@@ -4,6 +4,7 @@
 
 
 ##-----------------------------------------------------------------------------
-ceil <- function(x)
-    ceiling(x)
+ceil <- function(x) {
+    return(ceiling(x))
+}
 
