@@ -9,9 +9,9 @@ test.jet.colors <- function(input, expected) {
     identical(output, expected)
 }
 
-jet.m0.expected <- character(0)
-jet.m1.expected <- "#00FFFF"
-jet.m8.expected <- c("#0000FF",
+jet.expected.m0 <- character(0)
+jet.expected.m1 <- "#00FFFF"
+jet.expected.m8 <- c("#0000FF",
                      "#0080FF",
                      "#00FFFF",
                      "#80FF80",
@@ -20,7 +20,7 @@ jet.m8.expected <- c("#0000FF",
                      "#FF0000",
                      "#800000")
 
-test.jet.colors(list(n = 0), jet.m0.expected)
-test.jet.colors(list(n = 1), jet.m1.expected)
-test.jet.colors(list(n = 8), jet.m8.expected)
+test.jet.colors(list(n = 0), jet.expected.m0)
+test.jet.colors(list(n = 1), jet.expected.m1)
+test.jet.colors(list(n = 8), jet.expected.m8)
 
